@@ -6,7 +6,7 @@
 namespace esphome {
 namespace ble_rssi {
 
-static const char *TAG = "ble_rssi";
+static const char *const TAG = "ble_rssi";
 
 void BLERSSISensor::dump_config() { LOG_SENSOR("", "BLE RSSI Sensor", this); }
 
