@@ -4,9 +4,9 @@
 namespace esphome {
 namespace servo {
 
-static const char *TAG = "servo";
+static const char *const TAG = "servo";
 
-uint32_t global_servo_id = 1911044085ULL;
+uint32_t global_servo_id = 1911044085ULL;  // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
 
 void Servo::dump_config() {
   ESP_LOGCONFIG(TAG, "Servo:");
