@@ -5,7 +5,7 @@
 namespace esphome {
 namespace ssd1331_base {
 
-static const char *TAG = "ssd1331";
+static const char *const TAG = "ssd1331";
 
 static const uint16_t BLACK = 0;
 static const uint16_t WHITE = 0xffff;
@@ -97,7 +97,7 @@ void SSD1331::update() {
 }
 void SSD1331::set_brightness(float brightness) {
   // validation
-  this->brightness_ = clamp(brightness, 0, 1);
+  this->brightness_ = clamp(brightness, 0.0F, 1.0F);
   // now write the new brightness level to the display
   this->command(SSD1331_CONTRASTA);  // 0x81
   this->command(int(SSD1331_MAX_CONTRASTA * (this->brightness_)));
