@@ -6,12 +6,13 @@
 namespace esphome {
 namespace xiaomi_lywsd02 {
 
-static const char *TAG = "xiaomi_lywsd02";
+static const char *const TAG = "xiaomi_lywsd02";
 
 void XiaomiLYWSD02::dump_config() {
   ESP_LOGCONFIG(TAG, "Xiaomi LYWSD02");
   LOG_SENSOR("  ", "Temperature", this->temperature_);
   LOG_SENSOR("  ", "Humidity", this->humidity_);
+  LOG_SENSOR("  ", "Battery Level", this->battery_level_);
 }
 
 bool XiaomiLYWSD02::parse_device(const esp32_ble_tracker::ESPBTDevice &device) {
@@ -44,6 +45,8 @@ bool XiaomiLYWSD02::parse_device(const esp32_ble_tracker::ESPBTDevice &device) {
       this->temperature_->publish_state(*res->temperature);
     if (res->humidity.has_value() && this->humidity_ != nullptr)
       this->humidity_->publish_state(*res->humidity);
+    if (res->battery_level.has_value() && this->battery_level_ != nullptr)
+      this->battery_level_->publish_state(*res->battery_level);
     success = true;
   }
 
